==> elasticsearch-0.90.1-sources.jar: org/elasticsearch/common/transport/DummyTransportAddress.java <==
/*
 * Licensed to ElasticSearch and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. ElasticSearch licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.common.transport;

import org.elasticsearch.common.io.stream.StreamInput;
import org.elasticsearch.common.io.stream.StreamOutput;

import java.io.IOException;

/**
 *
 */
public class DummyTransportAddress implements TransportAddress {

    public static final DummyTransportAddress INSTANCE = new DummyTransportAddress();

    DummyTransportAddress() {
    }

    @Override
    public short uniqueAddressTypeId() {
        return 0;
    }

    @Override
    public boolean match(String otherAddress) {
        return false;
    }

    @Override
    public boolean sameHost(TransportAddress otherAddress) {
        return false;
    }

    @Override
    public void readFrom(StreamInput in) throws IOException {
    }

    @Override
    public void writeTo(StreamOutput out) throws IOException {
    }
}

==> elasticsearch-1.5.2-sources.jar: org/elasticsearch/common/transport/DummyTransportAddress.java <==
/*
 * Licensed to Elasticsearch under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.common.transport;

import org.elasticsearch.common.io.stream.StreamInput;
import org.elasticsearch.common.io.stream.StreamOutput;

import java.io.IOException;

/**
 *
 */
public class DummyTransportAddress implements TransportAddress {

    public static final DummyTransportAddress INSTANCE = new DummyTransportAddress();

    DummyTransportAddress() {
    }

    @Override
    public short uniqueAddressTypeId() {
        return 0;
    }

    @Override
    public boolean sameHost(TransportAddress other) {
        return other == INSTANCE;
    }

    @Override
    public void readFrom(StreamInput in) throws IOException {
    }

    @Override
    public void writeTo(StreamOutput out) throws IOException {
    }
}
